@@ -434,6 +434,11 @@ class ExcelDashboarder:
         ws_the_worksheet: Worksheet = wb_workbook.add_worksheet(name=str_worksheet_label)
         ws_the_worksheet.hide_gridlines(option=2)
 
+        ws_the_worksheet.outline_settings(
+            symbols_below=False,
+            symbols_right=False
+        )
+
         # for each "worksheet.set_column"
         if self.const_str__config_label__str_ws_set_column in dict_worksheet_config:
             for i_set_column in dict_worksheet_config[self.const_str__config_label__str_ws_set_column]:
